@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2024 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2024-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -8,10 +8,6 @@
 #include "kaddressbook_export.h"
 #include <PimCommonActivities/ActivitiesBaseManager>
 #include <QObject>
-namespace KActivities
-{
-class Consumer;
-}
 class LdapActivities;
 class AccountActivities;
 class KADDRESSBOOK_EXPORT ActivitiesManager : public PimCommonActivities::ActivitiesBaseManager
@@ -23,16 +19,11 @@ public:
     explicit ActivitiesManager(QObject *parent = nullptr);
     ~ActivitiesManager() override;
 
-    [[nodiscard]] bool enabled() const override;
-    void setEnabled(bool newEnabled);
-
     [[nodiscard]] LdapActivities *ldapActivities() const;
 
     AccountActivities *accountActivities() const;
 
 private:
     LdapActivities *const mLdapActivities;
-    KActivities::Consumer *const mActivitiesConsumer;
     AccountActivities *const mAccountActivities;
-    bool mEnabled = false;
 };
