@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2024-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -20,7 +20,6 @@ KCMKaddressbookActivitiesConfig::KCMKaddressbookActivitiesConfig(QObject *parent
     , mActivities(new QCheckBox(i18n("Enabled"), widget()))
 {
     auto lay = new QVBoxLayout(widget());
-    lay->setContentsMargins({});
     lay->addWidget(mActivities);
     lay->addStretch(1);
     connect(mActivities, &QCheckBox::clicked, this, &KCMKaddressbookActivitiesConfig::slotConfigChanged);
@@ -34,6 +33,7 @@ void KCMKaddressbookActivitiesConfig::slotConfigChanged()
 void KCMKaddressbookActivitiesConfig::save()
 {
     Settings::self()->setEnabledActivities(mActivities->isChecked());
+    setNeedsSave(false);
 }
 
 void KCMKaddressbookActivitiesConfig::load()
