@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -23,7 +23,7 @@ public:
     explicit PluginInterface(QObject *parent = nullptr);
     ~PluginInterface() override;
 
-    enum ImportExportAction {
+    enum class ImportExportAction : uint8_t {
         Import = 0,
         Export = 1
     };
@@ -52,7 +52,7 @@ public:
 protected:
     QList<QAction *> mImportActions;
     QList<QAction *> mExportActions;
-    ImportExportAction mImportExportAction = Import;
+    ImportExportAction mImportExportAction = ImportExportAction::Import;
     Akonadi::Collection mDefaultCollection;
     QItemSelectionModel *mItemSelectionModel = nullptr;
 };
