@@ -5,6 +5,8 @@
 */
 
 #include "pluginmanager.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "libkaddressbookexportimport_debug.h"
 #include "plugin.h"
 
@@ -41,7 +43,7 @@ namespace
 {
 QString pluginVersion()
 {
-    return QStringLiteral("1.0");
+    return u"1.0"_s;
 }
 }
 
@@ -74,9 +76,9 @@ private:
 
 bool PluginManagerPrivate::initializePlugins()
 {
-    const QList<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("pim6/kaddressbook/importexportplugin"));
+    const QList<KPluginMetaData> plugins = KPluginMetaData::findPlugins(u"pim6/kaddressbook/importexportplugin"_s);
 
-    const QPair<QStringList, QStringList> pair = PimCommon::PluginUtil::loadPluginSetting(configGroupName(), configPrefixSettingKey());
+    const PimCommon::PluginUtil::PluginsStateList pair = PimCommon::PluginUtil::loadPluginSetting(configGroupName(), configPrefixSettingKey());
 
     QListIterator<KPluginMetaData> i(plugins);
     i.toBack();
@@ -87,8 +89,10 @@ bool PluginManagerPrivate::initializePlugins()
         // 1) get plugin data => name/description etc.
         info.pluginData = PimCommon::PluginUtil::createPluginMetaData(data);
         // 2) look at if plugin is activated
-        const bool isPluginActivated =
-            PimCommon::PluginUtil::isPluginActivated(pair.first, pair.second, info.pluginData.mEnableByDefault, info.pluginData.mIdentifier);
+        const bool isPluginActivated = PimCommon::PluginUtil::isPluginActivated(pair.enabledPluginList,
+                                                                                pair.disabledPluginList,
+                                                                                info.pluginData.mEnableByDefault,
+                                                                                info.pluginData.mIdentifier);
         info.isEnabled = isPluginActivated;
         info.metaDataFileNameBaseName = QFileInfo(data.fileName()).baseName();
         info.data = data;
@@ -135,12 +139,12 @@ QList<PimCommon::PluginUtilData> PluginManagerPrivate::pluginDataList() const
 
 QString PluginManagerPrivate::configGroupName() const
 {
-    return QStringLiteral("KAddressBookPluginImportExport");
+    return u"KAddressBookPluginImportExport"_s;
 }
 
 QString PluginManagerPrivate::configPrefixSettingKey() const
 {
-    return QStringLiteral("KAddressBookImportExportPlugin");
+    return u"KAddressBookImportExportPlugin"_s;
 }
 
 Plugin *PluginManagerPrivate::pluginFromIdentifier(const QString &id)
